%global baserelease 1
%global major 0
%define libname %mklibname lldb %major
%define devname %mklibname -d lldb

%global toolchain clang
%global lldb_version 15.0.6
#global rc_ver 3
%global lldb_srcdir %{name}-%{lldb_version}%{?rc_ver:rc%{rc_ver}}.src

Name:		lldb
Version:	%{lldb_version}%{?rc_ver:~rc%{rc_ver}}
Release:	%mkrel %{baserelease}%{?rc_ver:.rc%{rc_ver}}
Summary:	Next generation high-performance debugger
Group:		Development/Tools

License:	NCSA
URL:		https://lldb.llvm.org/
Source0:	https://github.com/llvm/llvm-project/releases/download/llvmorg-%{lldb_version}%{?rc_ver:-rc%{rc_ver}}/%{lldb_srcdir}.tar.xz
Source1:	https://github.com/llvm/llvm-project/releases/download/llvmorg-%{lldb_version}%{?rc_ver:-rc%{rc_ver}}/%{lldb_srcdir}.tar.xz.sig
Source2:	release-keys.asc

# TODO: Drop once 16.0.0 is out
Patch0:		https://github.com/llvm/llvm-project/commit/6f59f302e4358b4dc869bc298c2b9c06aa716b60.diff
##

BuildRequires:	clang
BuildRequires:	cmake
BuildRequires:	ninja-build
BuildRequires:  llvm-devel = %{version}
BuildRequires:	llvm-test >= %{version}
BuildRequires:  clang-devel >= %{version}
BuildRequires:  ncurses-devel
BuildRequires:	pkgconfig(libedit)
BuildRequires:  swig
BuildRequires:  llvm-static >= %{version}
BuildRequires:  pkgconfig(libffi)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  libedit-devel
BuildRequires:	python3-lit

Requires:	python3-lldb

# For origin certification
BuildRequires:	gnupg2

%description
LLDB is a next generation, high-performance debugger. It is built as a set
of reusable components which highly leverage existing libraries in the
larger LLVM Project, such as the Clang expression parser and LLVM
disassembler.

%package -n %libname
Summary:	Library for LLDB
Group:		Development/Other

%description -n %libname
The package contains library for the LLDB debugger.

%package -n %devname
Summary:	Development header files for LLDB
Group:		Development/Other
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
# (tv) fix broken deps:
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}devel\\(libclang

%description -n %devname
The package contains header files for the LLDB debugger.

%package -n python3-lldb
%{?python_provide:%python_provide python3-lldb}
Summary:	Python module for LLDB
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-setuptools
Requires:	python3-six
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description -n python3-lldb
The package contains the LLDB Python module.

%prep
%{gpgverify} --keyring='%{SOURCE2}' --signature='%{SOURCE1}' --data='%{SOURCE0}'
%autosetup -n %{lldb_srcdir} -p2

%build
# FC compatibility:
%global _vpath_builddir _build
%cmake  -GNinja \
	-DCMAKE_BUILD_TYPE=RelWithDebInfo \
	-DCMAKE_SKIP_RPATH:BOOL=ON \
	-DLLVM_LINK_LLVM_DYLIB:BOOL=ON \
	-DLLVM_CONFIG:FILEPATH=/usr/bin/llvm-config \
	\
	-DLLDB_DISABLE_CURSES:BOOL=OFF \
	-DLLDB_DISABLE_LIBEDIT:BOOL=OFF \
	-DLLDB_DISABLE_PYTHON:BOOL=OFF \
%if 0%{?__isa_bits} == 64
	-DLLVM_LIBDIR_SUFFIX=64 \
%else
	-DLLVM_LIBDIR_SUFFIX= \
%endif
	\
	-DPYTHON_EXECUTABLE:STRING=%{__python3} \
	-DPYTHON_VERSION_MAJOR:STRING=$(%{__python3} -c "import sys; print(sys.version_info.major)") \
	-DPYTHON_VERSION_MINOR:STRING=$(%{__python3} -c "import sys; print(sys.version_info.minor)") \
	-DLLVM_EXTERNAL_LIT=%{_bindir}/lit \
	-DCLANG_LINK_CLANG_DYLIB=ON \
	-DLLVM_LIT_ARGS="-sv \
	--path %{_libdir}/llvm" \

%cmake_build

%install
%cmake_install

# remove static libraries
rm -fv %{buildroot}%{_libdir}/*.a

# python: fix binary libraries location
liblldb=$(basename $(readlink -e %{buildroot}%{_libdir}/liblldb.so))
ln -vsf "../../../${liblldb}" %{buildroot}%{python3_sitearch}/lldb/_lldb.so
%py_byte_compile %{__python3} %{buildroot}%{python3_sitearch}/lldb

# remove bundled six.py
rm -f %{buildroot}%{python3_sitearch}/six.*


%check


%files
%license LICENSE.TXT
%{_bindir}/*lldb*
%{_libdir}/liblldbIntelFeatures.so.*

%files -n %libname
%{_libdir}/liblldb.so.*

%files -n %devname
%{_includedir}/lldb
%{_libdir}/*.so

%files -n python3-lldb
%{python3_sitearch}/lldb


%changelog
* Fri Dec 09 2022 tv <tv> 15.0.6-1.mga9
+ Revision: 1919675
- Update to LLVM 15.0.6

* Tue Nov 15 2022 tv <tv> 15.0.4-2.mga9
+ Revision: 1907458
- Update to LLVM 15.0.4

* Mon Oct 03 2022 tv <tv> 15.0.0-2.mga9
+ Revision: 1894446
- Backport compat patches for swig 4.1.0 (rhbz#2128646)

* Wed Sep 21 2022 tv <tv> 15.0.0-1.mga9
+ Revision: 1891261
- Update to LLVM 15.0.0

* Fri Jun 17 2022 tv <tv> 14.0.5-1.mga9
+ Revision: 1864666
- Update to LLVM 14.0.5

* Wed Mar 30 2022 tv <tv> 14.0.0-1.mga9
+ Revision: 1834897
- Update to LLVM 14.0.0

* Mon Mar 21 2022 kekepower <kekepower> 13.0.1-2.mga9
+ Revision: 1812513
- Rebuild for Python 3.10

* Fri Feb 04 2022 tv <tv> 13.0.1-1.mga9
+ Revision: 1771387
- Update to 13.0.1 final
- Remove -Wno-error=format-security from build
  This does not seem necessary anymore.

* Wed Oct 20 2021 tv <tv> 13.0.0-1.mga9
+ Revision: 1752297
- 13.0.0 Release

* Mon Jul 19 2021 tv <tv> 12.0.1-1.mga9
+ Revision: 1737062
- 12.0.1 Release
- BuildRequire setuptools explicitly

* Fri Apr 16 2021 tv <tv> 12.0.0-11.1.mga9
+ Revision: 1716131
- 12.0.0 final

* Fri Apr 09 2021 tv <tv> 12.0.0-11.rc5.mga9
+ Revision: 1714257
- 12.0.0 RC5

* Fri Apr 02 2021 tv <tv> 12.0.0-8.rc4.mga9
+ Revision: 1712637
- 12.0.0 RC4

* Fri Mar 12 2021 tv <tv> 12.0.0-8.rc3.mga9
+ Revision: 1701747
- LLVM 12.0.0 rc3

* Tue Mar 02 2021 tv <tv> 12.0.0-5.rc2.mga9
+ Revision: 1696132
- Apply upstream D97721

* Mon Mar 01 2021 tv <tv> 12.0.0-2.rc2.mga9
+ Revision: 1695616
- 12.0.0-rc2 release

* Thu Jan 07 2021 tv <tv> 11.0.1-3.mga8
+ Revision: 1669446
- LLVM 11.0.1 final

* Tue Dec 22 2020 tv <tv> 11.0.1-2.rc2.mga8
+ Revision: 1662972
- llvm 11.0.1-rc2

* Fri Dec 04 2020 tv <tv> 11.0.1-1.rc1.mga8
+ Revision: 1652565
- 11.0.1-rc1

* Wed Nov 25 2020 tv <tv> 11.0.0-1.mga8
+ Revision: 1649343
- 11.0.0

* Thu Oct 08 2020 akien <akien> 10.0.1-1.mga8
+ Revision: 1632804
- Version 10.0.1

* Tue Jul 21 2020 tv <tv> 10.0.0-6.mga8
+ Revision: 1607641
- Use ninja and according macros as build system

* Fri Jun 19 2020 tv <tv> 10.0.0-5.mga8
+ Revision: 1596591
- Finer grain specification of python3-lldb deps

* Thu Jun 11 2020 tv <tv> 10.0.0-4.mga8
+ Revision: 1592264
- cp config.* from rpm-setup

* Tue Mar 24 2020 tv <tv> 10.0.0-1.mga8
+ Revision: 1559506
- 10.0.0 final
- 10.0.0 final

* Thu Mar 19 2020 tv <tv> 10.0.0-0.5.rc5.mga8
+ Revision: 1558096
- 10.0.0 rc5

* Sun Mar 15 2020 tv <tv> 10.0.0-0.4.rc4.mga8
+ Revision: 1556558
- 10.0.0 rc4

* Thu Mar 05 2020 tv <tv> 10.0.0-0.3.rc3.mga8
+ Revision: 1554128
- 10.0.0 RC3

* Tue Feb 18 2020 tv <tv> 10.0.0-0.2.rc2.mga8
+ Revision: 1540293
- 10.0.0 rc2

* Wed Feb 12 2020 tv <tv> 10.0.0-0.1.rc1.mga8
+ Revision: 1509050
- 10.0.0 rc1
+ wally <wally>
- build with new cmake macros

* Sat Sep 21 2019 tv <tv> 9.0.0-1.mga8
+ Revision: 1444212
- 9.0.0 Release

* Tue Sep 17 2019 tv <tv> 9.0.0-0.1.rc3.mga8
+ Revision: 1442783
- 9.0.0-rc3 Release

* Sun Sep 01 2019 daviddavid <daviddavid> 8.0.0-2.mga8
+ Revision: 1436126
- port to Python 3

* Mon Apr 15 2019 ghibo <ghibo> 8.0.0-1.mga7
+ Revision: 1390762
- Update to release 8.0.0.
- Rediff Patch1.

* Sun Dec 30 2018 tv <tv> 7.0.1-1.mga7
+ Revision: 1346948
- 7.0.1

* Mon Sep 24 2018 tv <tv> 7.0.0-1.mga7
+ Revision: 1303455
- new release
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Thu Jun 28 2018 tv <tv> 6.0.1-1.mga7
+ Revision: 1240608
- 6.0.1

* Sun May 27 2018 tv <tv> 6.0.1-0.1.rc1.mga7
+ Revision: 1232481
- 6.0.1-rc1 Release

* Wed Mar 21 2018 tv <tv> 6.0.0-1.mga7
+ Revision: 1210944
- patch 1: fix linking
- "workaround" linking issues
- new release

* Tue Dec 26 2017 tv <tv> 5.0.1-1.mga7
+ Revision: 1185187
- new release
- move plugin into libdir

* Thu Oct 19 2017 tv <tv> 5.0.0-1.mga7
+ Revision: 1172778
- drop merged patches
- new release

* Fri Sep 22 2017 tv <tv> 4.0.1-4.mga7
+ Revision: 1157018
- relax requires

* Fri Sep 22 2017 tv <tv> 4.0.1-3.mga7
+ Revision: 1156947
- temporary explicitely BR clang
- New release
- Backport lldb r303907 (rhbz#1356140)
- Adjust python sys.path so lldb can find readline.so
- Rename Python 2 binary package to python2-lldb

* Wed Mar 29 2017 tmb <tmb> 3.9.1-4.mga6
+ Revision: 1095141
- rebuild for armv7hl

* Tue Mar 28 2017 tmb <tmb> 3.9.1-3.mga6
+ Revision: 1095108
- rebuild for arm5tl

* Tue Mar 28 2017 tmb <tmb> 3.9.1-2.mga6
+ Revision: 1095060
- rebuild with new llvm and clang

* Sat Jan 07 2017 ghibo <ghibo> 3.9.1-1.mga6
+ Revision: 1080456
- Update to release 3.9.1.
- Removed Patch0 (D15067) merged upstream
- Sync Patches (MIUtilParse) with Fedora.

* Tue Jul 12 2016 tmb <tmb> 3.8.1-1.mga6
+ Revision: 1041264
- update to 3.8.1 (maintenance release)

* Thu May 19 2016 akien <akien> 3.8.0-4.mga6
+ Revision: 1016999
- devel pkg: provide lldb-devel
- Use upstream RPM macros

* Mon May 02 2016 tv <tv> 3.8.0-3.mga6
+ Revision: 1008695
- fix devel broken deps
- fix requires on python-six

* Mon Mar 14 2016 tv <tv> 3.8.0-2.mga6
+ Revision: 990524
- use proper BR now that clang eventually got build
- submit to core/release

* Sat Mar 12 2016 tv <tv> 3.8.0-1.mga6
+ Revision: 989646
- fix llvm-config path
- fix build if %%__global_ldflags is not set
- temp BR fix as BS fails to upload build packages after hours
- new release
- imported package lldb

